@@ -6,7 +6,7 @@
 # http://www.apache.org/licenses/LICENSE-2.0OA
 #
 # Authors:
-# - Wen Guan, <wen.guan@cern.ch>, 2019 - 2022
+# - Wen Guan, <wen.guan@cern.ch>, 2019 - 2023
 
 import copy
 import datetime
@@ -40,6 +40,8 @@ class Transformer(BaseAgent):
 
     def __init__(self, num_threads=1, poll_period=1800, retries=3, retrieve_bulk_size=10,
                  message_bulk_size=10000, **kwargs):
+        self.set_max_workers()
+        num_threads = self.max_number_workers
         super(Transformer, self).__init__(num_threads=num_threads, name='Transformer', **kwargs)
         self.config_section = Sections.Transformer
         self.poll_period = int(poll_period)
